@@ -13,7 +13,6 @@
 #include "SFormatHandler.h"
 #include "SerialCtrl.h"
 #include "wctrl_data.h"
-//#include "Delay.h"
 #include <string>
 
 
@@ -139,8 +138,8 @@ struct FZtatHandler::pImpl {
       n = con->recv(&recv_ch, 1, LongTimeout);
       if ((n < 1) || (recv_ch != '0')) {
 	// !!! gC
-	fprintf(stderr, "n = %d, recv_ch = %c\n", n, recv_ch);
-	fprintf(stderr, "writing fail: address: %p\n", address);
+	//fprintf(stderr, "n = %d, recv_ch = %c\n", n, recv_ch);
+	//fprintf(stderr, "writing fail: address: %p\n", address);
 	return false;
       }
 
@@ -215,8 +214,7 @@ struct FZtatHandler::pImpl {
 
     // MeƃGR[obNƂr
     char* buffer = new char[send_size];
-    enum { NoTimeout = -1 };
-    n = args.con->recv(buffer, send_size, NoTimeout);
+    n = args.con->recv(buffer, send_size, Timeout);
     if (n != static_cast<int>(send_size)) {
       // !!!
       error_message = "??? 2";
@@ -248,8 +246,7 @@ struct FZtatHandler::pImpl {
       return false;
     }
 
-
-    const char* output_format = "\r%3.1f %% complete.";
+    const char* output_format = "\r%3.1f %% complete. ";
     double percent = 100.0 * info->lines_counter / info->lines_max;
     fprintf(stderr, output_format, percent);
     ++info->lines_counter;
@@ -262,7 +259,6 @@ struct FZtatHandler::pImpl {
 
       // AhXȂAf[^i[Ɠ]̏s
       unsigned long write_address = info->getWriteAddress(srec->address);
-      //fprintf(stderr, "srec->address: %08x, %08x, %08x\n", srec->address, write_address, info->address);
       if (info->address != write_address) {
 
 	if (! info->filled) {
@@ -293,7 +289,6 @@ struct FZtatHandler::pImpl {
       info->filled = true;
     }
     // ŏIs̏̌ŁAcĂf[^Ώ݂s
-    //printf("%d, %d\n", info->lines_counter, info->lines_max);
     if ((info->lines_counter >= info->lines_max) && (info->filled)) {
 
       // f[^Iɏ
@@ -403,7 +398,8 @@ bool FZtatHandler::connect(const char* serialDevice, long baudrate) {
   pimpl->send_baudrate = baudrate;
   int ret = pimpl->args.con->connect(serialDevice, pImpl::FirstBaudrate);
   if (ret != 0) {
-    pimpl->error_message = "Coudn't connect to target CPU";
+    pimpl->error_message = pimpl->args.con->what();
+    // "Coudn't connect to target CPU";
     return false;
   } else {
     return true;
