@@ -8,6 +8,7 @@
 */
 
 #include "SFormatHandler.h"
+#include <errno.h>
 #include <fstream>
 #include <string>
 
@@ -97,7 +98,7 @@ bool SFormatHandler::eachLines(LineHandler callback, void* args) {
 
   std::ifstream fd(pimpl->fname.c_str());
   if (! fd.is_open()) {
-    pimpl->error_message = "file is not found.";
+    pimpl->error_message = strerror(errno);
     return false;
   }
 
