@@ -13,6 +13,9 @@
 #include <memory>
 
 
+/*!
+  \brief S-Format nh
+*/
 class SFormatHandler {
   SFormatHandler(const SFormatHandler& rhs);
   SFormatHandler& operator = (const SFormatHandler& rhs);
@@ -21,6 +24,9 @@ class SFormatHandler {
   const std::auto_ptr<pImpl> pimpl;
 
 public:
+  /*!
+    \brief S-Format Ps̏Ǘ
+  */
   typedef struct {
     char type;
     char data_size;
