@@ -15,9 +15,14 @@
 #ifdef MONITOR
 #include "LoaderTargetSimulator.h"
 #endif
+#include "FileToArgs.h"
+#include "SearchFilePath.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include <string>
+#include <fstream>
+
+
+static const char* LogFileName = "sloader_log.txt";
 
 
 // !!! ̂Ash2writer ƋʂɂłȂȁH
@@ -36,24 +41,30 @@ static const long DefaultBaudrate = 115200;
 #endif
 
 
+/*!
+  \brief sloader ̈Ǘ
+*/
 class ArgsInfo {
 public:
   const char* sformatFile;
-  const char* serialDevice;
+  std::string serialDevice;
   long baudrate;
   long terminalBaudrate;
   const char* targetCpu;
   bool simulator;
+  bool record ;
 
   ArgsInfo(void)
     : sformatFile(NULL), serialDevice(DefaultSerialDevice),
-      baudrate(DefaultBaudrate),
-      targetCpu("SH7040"), simulator(false) {
+      baudrate(DefaultBaudrate), terminalBaudrate(DefaultBaudrate),
+      targetCpu("SH7040"), simulator(false), record(false) {
   }
 };
 
 
-static void printHelp(const char* progname) {
+static void printHelp(const char* progname,
+		      const char* device,
+		      long baudrate, long terminal_baudrate) {
   printf("usage:\n"
 	 "\t%s [options] <S-Fromat file>\n"
 	 "\n"
@@ -63,8 +74,10 @@ static void printHelp(const char* progname) {
 	 "--port=<PORT>\t\tspecify serial device. (default %s)\n"
 	 "--baudrate=<BAUDRATE>\tspecify send baudrate. (default %ld bps)\n"
 	 "--t_baudrate=<BAUDRATE>\tspecify terminal baudrate. "
-	 "(default %ld bps)\n",
-	 progname, DefaultSerialDevice, DefaultBaudrate, DefaultBaudrate);
+	 "(default %ld bps)\n"
+	 "-r, --record\treceive data record to \"%s\"\n"
+	 "\n",
+	 progname, device, baudrate, terminal_baudrate, LogFileName);
 }
 
 
@@ -93,9 +106,13 @@ static void parseArgs(ArgsInfo& info, int argc, char* argv[]) {
       exit(0);
 
     } else if ((! strcmp("-h", argv[i])) || (! strcmp("--help", argv[i]))) {
-      printHelp(argv[0]);
+      printHelp(argv[0], info.serialDevice.c_str(),
+		info.baudrate, info.terminalBaudrate);
       exit(0);
 
+    } else if ((! strcmp("-r", argv[i])) || (! strcmp("--record", argv[i]))) {
+      info.record = true;
+
     } else {
       // S-Format ̃t@CƂēo^
       info.sformatFile = argv[i];
@@ -104,7 +121,9 @@ static void parseArgs(ArgsInfo& info, int argc, char* argv[]) {
 }
 
 
-static void runTerminal(ConnectionInterface* con, long baudrate) {
+// !!! ̂Aminiterm ƓȂ̂ȂƂ
+static void runTerminal(ConnectionInterface* con, long baudrate,
+			ArgsInfo& args_info, std::ofstream& fout) {
 
   // ^[Qbg̃f[^MA^[~iւ̓͑M
   con->changeBaudrate(baudrate);
@@ -116,6 +135,11 @@ static void runTerminal(ConnectionInterface* con, long baudrate) {
     int n = con->recv(buf, BUFSIZ, 0);
     if (n > 0) {
       write(1, buf, n);
+      if (args_info.record) {
+	// L^t@Cւ̏o
+	fout.write(buf, n);
+	fout.flush();
+      }
     }
     n = sio.recv(buf, BUFSIZ, 100);
     if (n > 0) {
@@ -128,19 +152,39 @@ static void runTerminal(ConnectionInterface* con, long baudrate) {
 int main(int argc, char *argv[]) {
 
   // ̉
-  ArgsInfo info;
-  parseArgs(info, argc, argv);
+  std::vector<std::string> search_path;
+  search_path.push_back("./");
+  search_path.push_back("~/.beego/");
 
-  if (info.sformatFile == NULL) {
-    printf("no data file.\n");
-    // !!! --help ̓e\ׂȁH
+  ArgsInfo args_info;
+  std::string config_file;
+  FileToArgs file;
+  if (searchFilePath(config_file, "beegoconf", search_path)) {
+    file.load(config_file.c_str());
+    // ݒt@C̓eƂĈ
+    parseArgs(args_info, file.argc, file.argv);
+  }
+  parseArgs(args_info, argc, argv);
+
+  if (args_info.sformatFile == NULL) {
+    printf("no data file.\nTrye '%s --help' for more information.\n", argv[0]);
     exit(1);
   }
 
+  // L^t@CJ
+  std::ofstream fout;
+  if (args_info.record) {
+    fout.open(LogFileName);
+    if (! fout.is_open()) {
+      perror(LogFileName);
+      args_info.record = false;
+    }
+  }
+
   // ]t@C̃tH[}bgmF
-  SFormatHandler sformat(info.sformatFile);
+  SFormatHandler sformat(args_info.sformatFile);
   if (! sformat.eachLines(NULL, NULL)) {
-    printf("%s: %s\n", info.sformatFile, sformat.what());
+    printf("%s: %s\n", args_info.sformatFile, sformat.what());
     exit(1);
   }
 
@@ -148,16 +192,16 @@ int main(int argc, char *argv[]) {
   FZtatHandler fztat;
 #ifdef MONITOR
   LoaderTargetSimulator simulator(fztat);
-  if (info.simulator) {
+  if (args_info.simulator) {
     simulator.activate();
   }
 #else
   if (0) {
   }
 #endif
- else {
-    if (! fztat.connect(info.serialDevice, info.baudrate)) {
-      printf("%s : device is %s.\n", fztat.what(), info.serialDevice);
+  else {
+    if (! fztat.connect(args_info.serialDevice.c_str(), args_info.baudrate)) {
+      printf("%s : %s.\n", fztat.what(), args_info.serialDevice.c_str());
       exit(1);
     }
   }
@@ -166,7 +210,7 @@ int main(int argc, char *argv[]) {
   con->send("S", 1);
   if (! fztat.sendSrecData(sformat)) {
     // !!! error_message
-    fprintf(stderr, "%s: %s\n", info.serialDevice, fztat.what());
+    fprintf(stderr, "%s: %s\n", args_info.serialDevice.c_str(), fztat.what());
     exit(1);
   }
   // AhX̓]
@@ -182,7 +226,7 @@ int main(int argc, char *argv[]) {
 
 
   // ^[~i
-  runTerminal(con, info.terminalBaudrate);
+  runTerminal(con, args_info.terminalBaudrate, args_info, fout);
 
   return 0;
 }
